@@ -19,6 +19,7 @@ class quiver:
             url = urlStart+"?representative="+ticker
             
         elif len(ticker)>0:
+            urlStart = 'https://api.quiverquant.com/beta/historical/congresstrading'
             url = urlStart+"/"+ticker
         else:
             url = urlStart
@@ -26,8 +27,12 @@ class quiver:
         r = requests.get(url, headers=self.headers)
         j = json.loads(r.content)
         df = pd.DataFrame(j)
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df["ReportDate"] = pd.to_datetime(df["ReportDate"])
         df["TransactionDate"] = pd.to_datetime(df["TransactionDate"])
+
         return df
    
 
@@ -39,6 +44,9 @@ class quiver:
         r = requests.get(url, headers=self.headers)
         j = json.loads(r.content)
         df = pd.DataFrame(j)
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df["Date"] = pd.to_datetime(df["Date"])
         return df
 
@@ -50,6 +58,9 @@ class quiver:
         r = requests.get(url, headers=self.headers)
         j = json.loads(r.content)
         df = pd.DataFrame(j)
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df["Date"] = pd.to_datetime(df["Date"])
         return df    
     
@@ -61,7 +72,9 @@ class quiver:
         r = requests.get(url, headers=self.headers)
         j = json.loads(r.content)
         df = pd.DataFrame(j)
-        
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         if len(ticker)>0:
             df["Date"] = pd.to_datetime(df["Date"])
             
@@ -75,6 +88,9 @@ class quiver:
 
         r = requests.get(url, headers=self.headers)
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         return df
 
     
@@ -86,18 +102,24 @@ class quiver:
 
         r = requests.get(url, headers=self.headers)
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df["Date"] = pd.to_datetime(df["Date"])
         return df
         
     def insiders(self, ticker=""):
         if len(ticker)>0:
-            url = "https://api.quiverquant.com/beta//live/insiders?ticker="+ticker
+            url = "https://api.quiverquant.com/beta/live/insiders?ticker="+ticker
         else:
-            url = "https://api.quiverquant.com/beta//live/insiders"
+            url = "https://api.quiverquant.com/beta/live/insiders"
          
         print("Drawing from: ", url)
         r = requests.get(url, headers=self.headers)
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
        # df["Date"] = pd.to_datetime(df["Date"])
         return df     
             
@@ -115,6 +137,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         return df
     
     def wallstreetbets(self, ticker="",date_from = "", date_to = "", yesterday=False):
@@ -140,7 +165,10 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
 
         df = pd.DataFrame(json.loads(r.content))
-
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
+        
         if not yesterday:
             try:
                 df["Date"] = pd.to_datetime(df["Time"], unit='ms')
@@ -165,6 +193,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         return df 
     
     def spacs(self, ticker = ""):
@@ -179,6 +210,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         return df 
     
     def flights(self, ticker = ""):
@@ -193,6 +227,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         return df 
         
         
@@ -208,6 +245,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         return df 
     
     def patents(self, ticker = ""):
@@ -223,6 +263,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
         
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df["Date"] = pd.to_datetime(df["Date"])
         
         return df
@@ -251,6 +294,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df["ReportPeriod"] = pd.to_datetime(df["ReportPeriod"], unit='ms')
 #         #Can edit this out once we get past May 25th
 #         values = []
@@ -293,6 +339,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df["ReportPeriod"] = pd.to_datetime(df["ReportPeriod"], unit='ms')
 #         #Can edit this out once we get past May 25th
 #         values = []
@@ -335,6 +384,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset. Contact chris@quiverquant.com with questions.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df['Datetime'] = pd.to_datetime(df["Time"], unit='ms')
         return df 
     
@@ -361,6 +413,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset. Contact chris@quiverquant.com with questions.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df['Datetime'] = pd.to_datetime(df["Time"], unit='ms')
         return df 
     
@@ -388,6 +443,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset. Contact chris@quiverquant.com with questions.')
             
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df['Datetime'] = pd.to_datetime(df["Time"], unit='ms')
         return df 
     
@@ -414,6 +472,9 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset. Contact chris@quiverquant.com with questions.')
 
         df = pd.DataFrame(json.loads(r.content))
+        if (len(df)==0) or (df.shape[0]==0):
+            print("No results found")
+            return df
         df['Datetime'] = pd.to_datetime(df["Time"], unit='ms')
         return df 
 
